==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/he.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "פעילויות",
    "An error occurred while loading activities" : "אירעה שגיאה בעת טעינת הפעילויות",
    "No activity yet" : "אין עדיין פעילויות",
    "Load more activities" : "טעינת פעילויות נוספות",
    "Copied!" : "הועתק!",
    "Not supported!" : "לא נתמך!",
    "Press ⌘-C to copy." : "יש ללחוץ על ‎⌘+C כדי להעתיק.",
    "Press Ctrl-C to copy." : "יש ללחוץ על Ctrl+C כדי להעתיק.",
    "{name} (invisible)" : "{name} (בלתי נראה)",
    "{name} (restricted)" : "{name} (מוגבל)",
    "in {path}" : "ב{path}",
    "This stream will show events like additions, changes & shares" : "הזרמת מידע זו מראה אירועים כגון תוספות, שינויים ושיתופים",
    "There are no events for this filter" : "אין אירועים לסינון זה",
    "Today" : "היום",
    "Yesterday" : "אתמול",
    "Personal activity feed for %s" : "הזנת פעילות עצמית עבור %s",
    "Your feed URL is invalid" : "כתובת ההזנה שגויה",
    "Your settings have been updated." : "ההגדרות שלך עודכנו",
    "Settings have been updated." : "ההגדרות עודכנו",
    "Mail" : "דואר",
    "Stream" : "הזרמת מידע",
    "All activities" : "כל הפעילויות",
    "By others" : "על ידי אחרים",
    "By you" : "על ידך",
    "\"remote user\"" : "\"משתמש מרוחק\"",
    "Hello %s" : "שלום %s",
    "Hello %s," : "שלום %s,",
    "There was some activity at %s" : "הייתה פעילות ב%s",
    "_and %n more _::_and %n more _" : ["ו־%n נוסף","ו־%n נוספים"],
    "Activity notification" : "דיווח פעילות",
    ", " : ",",
    "%s and %s" : "%s ו- %s",
    "Activity" : "פעילות",
    "Activity feed" : "דיווחי פעילות",
    "Configure the default activity settings for new users." : "הגדרת הגדרות הפעילות כבררת מחדל למשתמשים חדשים",
    "List your own actions in the stream" : "הצגת הפעולות שלך בהזנה",
    "Notify about your own actions via email" : "דיווח על האירועים שלך על בסיס דואר אלקטרוני",
    "You need to set up your email address before you can receive notification emails." : "יש להגדיר כתובת דואר אלקטרוני לפני שניתן יהיה לקבל דיווחים.",
    "Send emails:" : "שליחת הודעות דואר אלקטרוני:",
    "As soon as possible" : "מהר ככל האפשר",
    "Hourly" : "שעתי",
    "Daily" : "יומי",
    "Weekly" : "שבועי",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "נא לבחור עבור אילו מהפעילויות ברצונך לקבל התרעות בדוא״ל ואילו תופענה בתזרים הפעילויות של היישומון.",
    "Settings" : "הגדרות",
    "Enable RSS feed" : "לאפשר הזנת RSS",
    "No more events to load" : "אין אירועים נוספים לטעינה",
    "Files" : "קבצים",
    "Error loading activities" : "טעינת הפעילויות נכשלה",
    "No activities" : "אין פעילויות",
    "You are receiving this email because the following things happened at %s" : "הודעת דוא״ל זו הגיעה אליך עקב האירועים הבאים שקרו תחת %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ו־%n נוסף ","* ו־%n נוספים "]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/he.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "פעילויות",
    "An error occurred while loading activities" : "אירעה שגיאה בעת טעינת הפעילויות",
    "No activity yet" : "אין עדיין פעילויות",
    "Load more activities" : "טעינת פעילויות נוספות",
    "Copied!" : "הועתק!",
    "Not supported!" : "לא נתמך!",
    "Press ⌘-C to copy." : "יש ללחוץ על ‎⌘+C כדי להעתיק.",
    "Press Ctrl-C to copy." : "יש ללחוץ על Ctrl+C כדי להעתיק.",
    "Home" : "בית",
    "{name} (invisible)" : "{name} (בלתי נראה)",
    "{name} (restricted)" : "{name} (מוגבל)",
    "in {path}" : "ב{path}",
    "This stream will show events like additions, changes & shares" : "הזרמת מידע זו מראה אירועים כגון תוספות, שינויים ושיתופים",
    "There are no events for this filter" : "אין אירועים לסינון זה",
    "Today" : "היום",
    "Yesterday" : "אתמול",
    "Open file" : "פתיחת קובץ",
    "Personal activity feed for %s" : "הזנת פעילות עצמית עבור %s",
    "Your feed URL is invalid" : "כתובת ההזנה שגויה",
    "Your settings have been updated." : "ההגדרות שלך עודכנו",
    "Settings have been updated." : "ההגדרות עודכנו",
    "Mail" : "דואר",
    "Stream" : "הזרמת מידע",
    "All activities" : "כל הפעילויות",
    "By others" : "על ידי אחרים",
    "By you" : "על ידך",
    "\"remote user\"" : "\"משתמש מרוחק\"",
    "Hello %s" : "שלום %s",
    "Hello %s," : "שלום %s,",
    "There was some activity at %s" : "הייתה פעילות ב%s",
    "_and %n more _::_and %n more _" : ["ו־%n נוסף","ו־%n נוספים"],
    "Activity notification" : "דיווח פעילות",
    ", " : ",",
    "%s and %s" : "%s ו- %s",
    "Activity" : "פעילות",
    "Activity feed" : "דיווחי פעילות",
    "Default settings" : "הגדרות ברירת מחדל",
    "Configure the default activity settings for new users." : "הגדרת הגדרות הפעילות כבררת מחדל למשתמשים חדשים",
    "List your own actions in the stream" : "הצגת הפעולות שלך בהזנה",
    "Notify about your own actions via email" : "דיווח על האירועים שלך על בסיס דואר אלקטרוני",
    "You need to set up your email address before you can receive notification emails." : "יש להגדיר כתובת דואר אלקטרוני לפני שניתן יהיה לקבל דיווחים.",
    "Send emails:" : "שליחת הודעות דואר אלקטרוני:",
    "As soon as possible" : "מהר ככל האפשר",
    "Hourly" : "שעתי",
    "Daily" : "יומי",
    "Weekly" : "שבועי",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "נא לבחור עבור אילו מהפעילויות ברצונך לקבל התרעות בדוא״ל ואילו תופענה בתזרים הפעילויות של היישומון.",
    "Settings" : "הגדרות",
    "Enable RSS feed" : "לאפשר הזנת RSS",
    "RSS feed" : "ערוץ RSS",
    "No more events to load" : "אין אירועים נוספים לטעינה",
    "Files" : "קבצים",
    "Error loading activities" : "טעינת הפעילויות נכשלה",
    "No activities" : "אין פעילויות",
    "You are receiving this email because the following things happened at %s" : "הודעת דוא״ל זו הגיעה אליך עקב האירועים הבאים שקרו תחת %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ו־%n נוסף ","* ו־%n נוספים "]
},
"nplurals=2; plural=(n != 1);");
